summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmconeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmconeedit.h')
-rw-r--r--kpovmodeler/pmconeedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmconeedit.h b/kpovmodeler/pmconeedit.h
index f4e689fc..d5210124 100644
--- a/kpovmodeler/pmconeedit.h
+++ b/kpovmodeler/pmconeedit.h
@@ -35,12 +35,13 @@ class PMCone;
class PMConeEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMConeEdit with parent and name
*/
- PMConeEdit( TQWidget* parent, const char* name = 0 );
+ PMConeEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class PMCone;
public:
/**
- * Creates a PMConeEdit with parent and name
+ * Creates a PMConeEdit with tqparent and name
*/